summaryrefslogtreecommitdiffstats
path: root/experimental/tqtinterface/qt4/src/tools/tqglist.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'experimental/tqtinterface/qt4/src/tools/tqglist.cpp')
-rw-r--r--experimental/tqtinterface/qt4/src/tools/tqglist.cpp22
1 files changed, 11 insertions, 11 deletions
diff --git a/experimental/tqtinterface/qt4/src/tools/tqglist.cpp b/experimental/tqtinterface/qt4/src/tools/tqglist.cpp
index 944c27c98..07851ba5d 100644
--- a/experimental/tqtinterface/qt4/src/tools/tqglist.cpp
+++ b/experimental/tqtinterface/qt4/src/tools/tqglist.cpp
@@ -371,7 +371,7 @@ void TQGList::inSort( TQPtrCollection::Item d )
{
int index = 0;
register TQLNode *n = firstNode;
- while ( n && compareItems(n->data,d) < 0 ){ // tqfind position in list
+ while ( n && compareItems(n->data,d) < 0 ){ // find position in list
n = n->next;
index++;
}
@@ -530,14 +530,14 @@ bool TQGList::removeNode( TQLNode *n )
}
/*!
- Removes the item \a d from the list. Uses compareItems() to tqfind the item.
+ Removes the item \a d from the list. Uses compareItems() to find the item.
If \a d is 0, removes the current item.
*/
bool TQGList::remove( TQPtrCollection::Item d )
{
- if ( d && tqfind(d) == -1 )
+ if ( d && find(d) == -1 )
return FALSE;
TQLNode *n = unlink();
if ( !n )
@@ -553,7 +553,7 @@ bool TQGList::remove( TQPtrCollection::Item d )
bool TQGList::removeRef( TQPtrCollection::Item d )
{
- if ( tqfindRef(d) == -1 )
+ if ( findRef(d) == -1 )
return FALSE;
TQLNode *n = unlink();
if ( !n )
@@ -595,7 +595,7 @@ bool TQGList::removeAt( uint index )
/*!
Replaces the item at index \a index with \a d.
*/
-bool TQGList::tqreplaceAt( uint index, TQPtrCollection::Item d )
+bool TQGList::replaceAt( uint index, TQPtrCollection::Item d )
{
TQLNode *n = locate( index );
if ( !n )
@@ -714,7 +714,7 @@ void TQGList::clear()
begins at the first node; otherwise it begins at the current node.
*/
-int TQGList::tqfindRef( TQPtrCollection::Item d, bool fromStart )
+int TQGList::findRef( TQPtrCollection::Item d, bool fromStart )
{
register TQLNode *n;
int index;
@@ -725,7 +725,7 @@ int TQGList::tqfindRef( TQPtrCollection::Item d, bool fromStart )
n = curNode;
index = curIndex;
}
- while ( n && n->data != d ) { // tqfind exact match
+ while ( n && n->data != d ) { // find exact match
n = n->next;
index++;
}
@@ -740,7 +740,7 @@ int TQGList::tqfindRef( TQPtrCollection::Item d, bool fromStart )
current node.
*/
-int TQGList::tqfind( TQPtrCollection::Item d, bool fromStart )
+int TQGList::find( TQPtrCollection::Item d, bool fromStart )
{
register TQLNode *n;
int index;
@@ -751,7 +751,7 @@ int TQGList::tqfind( TQPtrCollection::Item d, bool fromStart )
n = curNode;
index = curIndex;
}
- while ( n && compareItems(n->data,d) ){ // tqfind equal match
+ while ( n && compareItems(n->data,d) ){ // find equal match
n = n->next;
index++;
}
@@ -765,7 +765,7 @@ int TQGList::tqfind( TQPtrCollection::Item d, bool fromStart )
Counts the number item \a d occurs in the list.
*/
-uint TQGList::tqcontainsRef( TQPtrCollection::Item d ) const
+uint TQGList::containsRef( TQPtrCollection::Item d ) const
{
register TQLNode *n = firstNode;
uint count = 0;
@@ -782,7 +782,7 @@ uint TQGList::tqcontainsRef( TQPtrCollection::Item d ) const
compareItems().
*/
-uint TQGList::tqcontains( TQPtrCollection::Item d ) const
+uint TQGList::contains( TQPtrCollection::Item d ) const
{
register TQLNode *n = firstNode;
uint count = 0;